#!/bin/bash
#
# source: http://hal.freedesktop.org/releases/DeviceKit-003.tar.gz
#
# maintainer: gmg (monpontet.gerard@neuf.fr)
#

#------------------Set Some Variables

soft="devicekit"
softversion="003"
packageversion="62.1"

arch="i486"
cpu="i686"

buildir=$(pwd)
srcpkg="$buildir/DeviceKit-003.tar.gz"
src="$buildir/DeviceKit-003"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# -----------------Extract sources and get ready to build

cd $buildir
rm -rf $src
tar -xvzf $srcpkg
rm -f $dest.tgz
rm -rf $dest

cd $src

#------------------Set correct permissions

chown -R root.root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

#------------------Start Configure

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure \
    --prefix=/usr \
    --sysconfdir=/etc \
    --mandir=/usr/man \
    --disable-static

make
make install DESTDIR=$dest

mkdir -p $dest/lib
mv $dest/etc/udev $dest/lib

( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)


( cd $dest/usr/man
  find . -type f -exec gzip -9 {} \;
  for i in $(find . -type l) ; do ln -s $(readlink $i).gz $i.gz ; rm $i ; done
)

#-------------------Prepare the documentation:

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a AUTHORS COPYING HACKING INSTALL NEWS README $dest/usr/doc/$soft-$softversion
( cd $dest/usr/doc/$soft-$softversion ; ln -s /usr/share/gtk-doc/html/devkit html )

#-----------------Make the slack-desc files

mkdir -p $dest/install
cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

         |-----handy-ruler-----------------------------------------------------|
devicekit: devicekit - is an abstraction for enumerating devices
devicekit:
devicekit: DeviceKit is an abstraction for enumerating devices and listening to
devicekit: device events. Any application on the system can access the
devicekit: org.freedesktop.DeviceKit service via the system message bus. On
devicekit: GNU/Linux, DeviceKit can be considered a simple D-Bus frontend to
devicekit: udev(7).
devicekit:
devicekit:
devicekit:
devicekit:
EODESC

#-------------------copy the build-script in /usr/src

mkdir -p $dest/usr/src/$soft-$softversion
cp -a $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.tgz
cd $buildir
md5sum $package.tgz > $package.md5